module Wylie
  CONSONANTS = {
    "kh" => [["\u0f41"], ["\u0f91"]],
    "k" => [["\u0f40"], ["\u0f90"]],
    "g" => [["\u0f42"], ["\u0f92"]],
    "gh" => [["\u0f42", "\u0fb7"], ["\u0f92", "\u0fb7"]],
    "g+h" => [["\u0f42", "\u0fb7"], ["\u0f92", "\u0fb7"]],
    "ng" => [["\u0f44"], ["\u0f94"]],
    "c" => [["\u0f45"], ["\u0f95"]],
    "ch" => [["\u0f46"], ["\u0f96"]],
    "j" => [["\u0f47"], ["\u0f97"]],
    "ny" => [["\u0f49"], ["\u0f99"]],
    "T" => [["\u0f4a"], ["\u0f9a"]],
    "-t" => [["\u0f4a"], ["\u0f9a"]],
    "Th" => [["\u0f4b"], ["\u0f9b"]],
    "-th" => [["\u0f4b"], ["\u0f9b"]],
    "D" => [["\u0f4c"], ["\u0f9c"]],
    "-d" => [["\u0f4c"], ["\u0f9c"]],
    "Dh" => [["\u0f4c", "\u0fb7"], ["\u0f9c", "\u0fb7"]],
    "D+h" => [["\u0f4c", "\u0fb7"], ["\u0f9c", "\u0fb7"]],
    "-dh" => [["\u0f4c", "\u0fb7"], ["\u0f9c", "\u0fb7"]],
    "-d+h" => [["\u0f4c", "\u0fb7"], ["\u0f9c", "\u0fb7"]],
    "N" => [["\u0f4e"], ["\u0f9e"]],
    "-n" => [["\u0f4e"], ["\u0f9e"]],
    "t" => [["\u0f4f"], ["\u0f9f"]],
    "th" => [["\u0f50"], ["\u0fa0"]],
    "d" => [["\u0f51"], ["\u0fa1"]],
    "dh" => [["\u0f51", "\u0fb7"], ["\u0fa1", "\u0fb7"]],
    "d+h" => [["\u0f51", "\u0fb7"], ["\u0fa1", "\u0fb7"]],
    "n" => [["\u0f53"], ["\u0fa3"]],
    "p" => [["\u0f54"], ["\u0fa4"]],
    "ph" => [["\u0f55"], ["\u0fa5"]],
    "b" => [["\u0f56"], ["\u0fa6"]],
    "bh" => [["\u0f56", "\u0fb7"], ["\u0fa6", "\u0fb7"]],
    "b+h" => [["\u0f56", "\u0fb7"], ["\u0fa6", "\u0fb7"]],
    "m" => [["\u0f58"], ["\u0fa8"]],
    "ts" => [["\u0f59"], ["\u0fa9"]],
    "tsh" => [["\u0f5a"], ["\u0faa"]],
    "dz" => [["\u0f5b"], ["\u0fab"]],
    "dzh" => [["\u0f5b", "\u0fb7"], ["\u0fab", "\u0fb7"]],
    "dz+h" => [["\u0f5b", "\u0fb7"], ["\u0fab", "\u0fb7"]],
    "w" => [["\u0f5d"], ["\u0fad"]],
    "zh" => [["\u0f5e"], ["\u0fae"]],
    "z" => [["\u0f5f"], ["\u0faf"]],
    "'" => [["\u0f60"], ["\u0fb0"]],
    "\u2018" => [["\u0f60"], ["\u0fb0 "]], # typographic quotes
    "\u2019" => [["\u0f60"], ["\u0fb0"]],
    "y" => [["\u0f61"], ["\u0fb1"]],
    "r" => [["\u0f62"], ["\u0fb2"]],
    "l" => [["\u0f63"], ["\u0fb3"]],
    "sh" => [["\u0f64"], ["\u0fb4"]],
    "Sh" => [["\u0f65"], ["\u0fb5"]],
    "-sh" => [["\u0f65"], ["\u0fb6"]],
    "s" => [["\u0f66"], ["\u0fb7"]],
    "h" => [["\u0f67"], ["\u0fb8"]],
    "W" => [["\u0f5d"], ["\u0fba"]],
    "Y" => [["\u0f61"], ["\u0fbb"]],
    "R" => [["\u0f6a"], ["\u0fbc"]],
    "f" => [["\u0f55"], ["\u0f39"]],
    "v" => [["\u0f56"], ["\u0f39"]],
  }

  VOWELS = {
    "a" => [["\u0F68"], ["\u0FB8"]],
    "A" => [["\u0f71"]],
    "i" => [["\u0f72"]],
    "I" => [["\u0f71", "\u0f72"]],
    "u" => [["\u0f74"]],
    "U" => [["\u0f71", "\u0f74"]],
    "e" => [["\u0f7a"]],
    "ai" => [["\u0f7b"]],
    "o" => [["\u0f7c"]],
    "au" => [["\u0f7d"]],
    "-i" => [["\u0f80"]],
    "-I" => [["\u0f71", "\u0f80"]]
  }

  SANSKRIT_VOWELS = {
    "r-i" => [["\u0fb2", "\u0f80"]],
    "r-I" => [["\u0fb2", "\u0f71", "\u0f80"]],
    "l-i" => [["\u0fb3", "\u0f80"]],
    "l-I" => [["\u0fb3", "\u0f71", "\u0f80"]]
  }

  COMPLEX_VOWELS = {
    "r-i " => [["\u0f62", "\u0f80"], ["\u0fb2", "\u0f80"]],
    "r-I " => [["\u0f62", "\u0f71", "\u0f80"], ["\u0fb2", "\u0f71", "\u0f80"]],
    "l-i " => [["\u0f63", "\u0f80"], ["\u0fb3", "\u0f80"]],
    "l-I " => [["\u0f63", "\u0f71", "\u0f80"], ["\u0fb3", "\u0f71", "\u0f80"]]
  }

  FINAL = {
    "M" => [["\u0f7e"]], # anusvara / bindu / circle above / nga ro
    "H" => [["\u0f7f"]], # visarga / rnam bcad
    "~M`" => [["\u0f82"]], # crescent", bindu & nada
    "~M" => [["\u0f83"]], # crescent & bindu
    "?" => [["\u0f84"]], # halanta / srog med
    "X" => [["\u0f37"]], # small circle under
    "~X" => [["\u0f35"]], # small circle w/ crescent under
    "^" => [["\u0f39}"]] # tsa-phru
  }

  OTHER = {
    "0" => [["\u0f20"]],
    "1" => [["\u0f21"]],
    "2" => [["\u0f22"]],
    "3" => [["\u0f23"]],
    "4" => [["\u0f24"]],
    "5" => [["\u0f25"]],
    "6" => [["\u0f26"]],
    "7" => [["\u0f27"]],
    "8" => [["\u0f28"]],
    "9" => [["\u0f29"]],
    " " => [["\u0f0b"]],
    "*" => [["\u0f0c"]],
    "/" => [["\u0f0d"]],
    "//" => [["\u0f0e"]],
    ";" => [["\u0f0f"]],
    "|" => [["\u0f11"]],
    "!" => [["\u0f08"]],
    ":" => [["\u0f14"]],
    "_" => [[" "]],
    "=" => [["\u0f34"]],
    "<" => [["\u0f3a"]],
    ">" => [["\u0f3b"]],
    "(" => [["\u0f3c"]],
    ")" => [["\u0f3d"]],
    "@" => [["\u0f04"]],
    "#" => [["\u0f05"]],
    "$" => [["\u0f06"]],
    "#" => [["\u0f07"]],
  }
end